ProjE
=====

.. currentmodule:: pykeen.models

.. autoclass:: ProjE
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~ProjE.hpo_default
      ~ProjE.loss_default_kwargs

   .. rubric:: Methods Summary

   .. autosummary::

      ~ProjE.score_h
      ~ProjE.score_hrt
      ~ProjE.score_t

   .. rubric:: Attributes Documentation

   .. autoattribute:: hpo_default
   .. autoattribute:: loss_default_kwargs

   .. rubric:: Methods Documentation

   .. automethod:: score_h
   .. automethod:: score_hrt
   .. automethod:: score_t
